flutter_gantt library
Classes
- GantDateHoliday
- Represents a holiday date in the Gantt chart.
- Gantt
- A customizable Gantt chart widget for Flutter.
-
GanttActivity<
T> - Represents an activity in the Gantt chart.
- GanttActivityAction
- An action that can be performed on a Gantt activity.
- GanttActivityRow
- A single row in the Gantt chart representing an activity.
- GanttCell
- A single cell representing an activity's duration in the Gantt chart.
- GanttController
- Controls the state and behavior of a Gantt widget.
- GanttRangeSelector
- Provides navigation controls for the Gantt chart timeline.
- GanttTheme
- A customizable theme for Gantt chart widgets.
Extensions
-
GanttActivityListExtension
on List<
GanttActivity> - Extension methods for working with lists of GanttActivity.
Typedefs
- GanttActivityOnChangedEvent = void Function(GanttActivity activity, DateTime? start, DateTime? end)
- Callback type for activity dates changes.
- MonthToText = String Function(BuildContext context, DateTime date)
- A function that converts a DateTime representing a month into its textual representation, using the given BuildContext.